@@ -1,15 +1,16 @@
 # Copyright (C) 2022 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+from __future__ import annotations
 
 
 import json
 import sys
 from dataclasses import Field, dataclass, field
-from typing import Dict, List
 
 
 _pyside_package_path = None
 _module_json_file_path = None
+_multimedia_libs = ["avcodec", "avformat", "avutil", "swresample", "swscale"]
 
 
 def set_pyside_package_path(p):
@@ -49,23 +50,24 @@ class ModuleData:
     name: str
     ext: str = ""
     # Libraries not related to Qt modules
-    lib: List[str] = field(default_factory=list)
+    lib: list[str] = field(default_factory=list)
     # Libraries related to Qt modules
-    qtlib: List[str] = field(default_factory=list)
+    qtlib: list[str] = field(default_factory=list)
     # Files from the Qt/qml directory
-    qml: List[str] = field(default_factory=list)
-    pyi: List[str] = field(default_factory=list)
-    translations: List[str] = field(default_factory=list)
-    typesystems: List[str] = field(default_factory=list)
-    include: List[str] = field(default_factory=list)
-    glue: List[str] = field(default_factory=list)
-    metatypes: List[str] = field(default_factory=list)
-    plugins: List[str] = field(default_factory=list)
+    qml: list[str] = field(default_factory=list)
+    pyi: list[str] = field(default_factory=list)
+    translations: list[str] = field(default_factory=list)
+    typesystems: list[str] = field(default_factory=list)
+    include: list[str] = field(default_factory=list)
+    glue: list[str] = field(default_factory=list)
+    doc_glue: list[str] = field(default_factory=list)
+    metatypes: list[str] = field(default_factory=list)
+    plugins: list[str] = field(default_factory=list)
 
     # For special cases when a file/directory doesn't fall into
     # the previous categories.
-    extra_dirs: List[str] = field(default_factory=list)
-    extra_files: List[str] = field(default_factory=list)
+    extra_dirs: list[str] = field(default_factory=list)
+    extra_files: list[str] = field(default_factory=list)
 
     # Once the object is created, this method will be executed
     # and automatically will initialize some of the files that are
@@ -87,6 +89,7 @@ class ModuleData:
         self.typesystems.append(f"typesystem_{_lo}.xml")
         self.include.append(f"Qt{self.name}/*.h")
         self.glue.append(f"qt{_lo}.cpp")
+        self.doc_glue.append(f"qt{_lo}.rst")
         if not len(self.metatypes):
             self.metatypes.append(f"qt6{_lo}_relwithdebinfo_metatypes.json")
 
@@ -122,6 +125,7 @@ class ModuleData:
         self.typesystems = [f"typesystems/{i}" for i in self.typesystems]
         self.include = [f"include/{i}" for i in self.include]
         self.glue = [f"glue/{i}" for i in self.glue]
+        self.doc_glue = [f"doc/{i}" for i in self.doc_glue]
 
     def macos_pyside_wrappers_lib(self, s):
         if s.startswith("Qt"):
@@ -130,7 +134,7 @@ class ModuleData:
             return f"{s}.*{self.ext}*"
 
     @classmethod
-    def get_fields(cls) -> Dict[str, Field]:
+    def get_fields(cls) -> dict[str, Field]:
         return cls.__dataclass_fields__
 
     @staticmethod
@@ -150,7 +154,7 @@ class ModuleData:
 # for each module that will be included in the wheel.
 
 # PySide wheel
-def wheel_files_pyside_essentials() -> List[ModuleData]:
+def wheel_files_pyside_essentials() -> list[ModuleData]:
     files = [
         module_QtCore(),
         module_QtGui(),
@@ -186,7 +190,7 @@ def wheel_files_pyside_essentials() -> List[ModuleData]:
 
 
 # PySide Addons wheel
-def wheel_files_pyside_addons() -> List[ModuleData]:
+def wheel_files_pyside_addons() -> list[ModuleData]:
     files = [
         module_Qt3DAnimation(),
         module_Qt3DCore(),
@@ -199,6 +203,7 @@ def wheel_files_pyside_addons() -> List[ModuleData]:
         module_QtCharts(),
         module_QtDataVisualization(),
         module_QtGraphs(),
+        module_QtGraphsWidgets(),
         module_QtMultimedia(),
         module_QtMultimediaWidgets(),
         module_QtNetworkAuth(),
@@ -224,6 +229,10 @@ def wheel_files_pyside_addons() -> List[ModuleData]:
         module_QtHttpServer(),
         module_QtLocation(),
         module_QtAsyncio(),
+        module_QtWebView(),
+        # This is not an actual module, but it's required in order
+        # to add the 'Quick' components of the WebView.
+        module_QtWebViewQuick(),
     ]
     return files
 
@@ -462,7 +471,9 @@ def module_QtQml() -> ModuleData:
         "libQt6QmlNetwork",
         "libQt6QmlWorkerScript",
         "libQt6QmlXmlListModel",
-        "libQt6QmlCompiler"
+        "libQt6QmlCompiler",
+        "libQt6QmlMeta",
+        "libQt6LabsPlatform",
     ]
 
     _include = [
@@ -489,6 +500,8 @@ def module_QtQml() -> ModuleData:
         "qt6qmlmodels_relwithdebinfo_metatypes.json",
         "qt6qmlworkerscript_relwithdebinfo_metatypes.json",
         "qt6qmlxmllistmodel_relwithdebinfo_metatypes.json",
+        "qt6qmlmeta_relwithdebinfo_metatypes.json",
+        "qt6labsplatform_relwithdebinfo_metatypes.json",
     ]
 
     _qml = [
@@ -526,6 +539,11 @@ def module_QtQml() -> ModuleData:
     data.qml.extend(_qml)
 
     data.extra_files.append("qmllint*")
+    # adds qmllint plugins
+    json_data_qmllint = get_module_json_data("QmlCompiler")
+    qml_lint_plugins = get_module_plugins(json_data_qmllint)
+    data.plugins += qml_lint_plugins
+
     data.extra_files.append("qmlformat*")
     data.extra_files.append("qmlls*")
 
@@ -549,6 +567,8 @@ def module_QtQuick() -> ModuleData:
         "qt6quicktest_relwithdebinfo_metatypes.json",
         "qt6quicktestutilsprivate_relwithdebinfo_metatypes.json",
         "qt6quicktimeline_relwithdebinfo_metatypes.json",
+        "qt6quickvectorimage_relwithdebinfo_metatypes.json",
+        "qt6quickvectorimagegeneratorprivate_relwithdebinfo_metatypes.json",
     ]
     _qtlib = [
         "libQt6QuickEffects",
@@ -562,15 +582,15 @@ def module_QtQuick() -> ModuleData:
         "libQt6QuickTest",
         "libQt6QuickTimeline",
         "libQt6QuickTimelineBlendTrees",
+        "libQt6QuickVectorImage",
+        "libQt6QuickVectorImageGenerator"
     ]
 
-    # Adding GraphicalEffects files
-    data.qml.append("Qt5Compat/GraphicalEffects")
-
     data.qtlib.extend(_qtlib)
     data.metatypes.extend(_metatypes)
     json_data = get_module_json_data("Quick")
     data.plugins = get_module_plugins(json_data)
+    data.extra_files.append("svgtoqml*")
 
     return data
 
@@ -589,6 +609,9 @@ def module_QtQuickControls2() -> ModuleData:
     data.qtlib.append("libQt6QuickControls2MaterialStyleImpl")
     data.qtlib.append("libQt6QuickControls2Universal")
     data.qtlib.append("libQt6QuickControls2UniversalStyleImpl")
+    # FluentWinUI3 Style is available for all platforms, even if it
+    # was originally intended for Windows.
+    data.qtlib.append("libQt6QuickControls2FluentWinUI3StyleImpl")
     if sys.platform == "win32":
         data.qtlib.append("libQt6QuickControls2WindowsStyleImpl")
     elif sys.platform == "darwin":
@@ -747,6 +770,7 @@ def module_QtQuick3D() -> ModuleData:
         "libQt63DQuickInput",
         "libQt63DQuickRender",
         "libQt63DQuickScene2D",
+        "libQt6Quick3DXr",
     ]
 
     _metatypes = [
@@ -767,6 +791,7 @@ def module_QtQuick3D() -> ModuleData:
         "qt6quick3druntimerender_relwithdebinfo_metatypes.json",
         "qt6quick3dutils_relwithdebinfo_metatypes.json",
         "qt6shadertools_relwithdebinfo_metatypes.json",
+        "qt6quick3dxr_relwithdebinfo_metatypes.json"
     ]
 
     json_data = get_module_json_data("Quick3DAssetImport")
@@ -774,6 +799,11 @@ def module_QtQuick3D() -> ModuleData:
     data.qtlib.extend(_qtlib)
     data.metatypes.extend(_metatypes)
     data.extra_files.append("Qt/plugins/assetimporters/libassimp*")
+    data.extra_files.append("qsb*")
+    data.extra_files.append("balsam*")
+
+    # Adding GraphicalEffects files
+    data.qml.append("Qt5Compat/GraphicalEffects")
 
     return data
 
@@ -839,6 +869,12 @@ def module_QtGraphs() -> ModuleData:
     return data
 
 
+def module_QtGraphsWidgets() -> ModuleData:
+    data = ModuleData("GraphsWidgets")
+
+    return data
+
+
 def module_QtMultimedia() -> ModuleData:
     data = ModuleData("Multimedia")
     data.qtlib.append("libQt6MultimediaQuick")
@@ -848,9 +884,14 @@ def module_QtMultimedia() -> ModuleData:
     data.translations.append("qtmultimedia_*")
     data.plugins = get_module_plugins(json_data)
 
-    if sys.platform == "win32":
-        data.extra_files.extend(["avcodec-60.dll", "avformat-60.dll", "avutil-58.dll",
-                                 "swresample-4.dll", "swscale-7.dll"])
+    linux_multimedia_libs = [f"Qt/lib/lib{lib}*.so*" for lib in _multimedia_libs]
+    linux_multimedia_libs.append("Qt/lib/libQt6FFmpegStub*.so*")
+    platform_files = {
+        "win32": [f"{lib}-*.dll" for lib in _multimedia_libs],
+        "darwin": [f"Qt/lib/lib{lib}.*.dylib" for lib in _multimedia_libs],
+        "linux": linux_multimedia_libs}
+    extra_files = platform_files.get(sys.platform, [])
+    data.extra_files.extend(extra_files)
 
     return data
 
@@ -995,6 +1036,8 @@ def module_QtSerialBus() -> ModuleData:
 def module_QtVirtualKeyboard() -> ModuleData:
     data = ModuleData("VirtualKeyboard")
     data.plugins.append("virtualkeyboard")
+    data.qtlib.append("libQt6VirtualKeyboardSettings")
+
     return data
 
 
@@ -1032,3 +1075,15 @@ def module_QtAsyncio() -> ModuleData:
 def module_QtExampleIcons() -> ModuleData:
     data = ModuleData("ExampleIcons")
     return data
+
+
+def module_QtWebView() -> ModuleData:
+    data = ModuleData("WebView")
+    json_data = get_module_json_data("WebView")
+    data.plugins = get_module_plugins(json_data)
+    return data
+
+
+def module_QtWebViewQuick() -> ModuleData:
+    data = ModuleData("WebViewQuick")
+    return data
