@@ -18,6 +18,7 @@ import os
 import struct
 import sys
 import typing
+import collections
 
 from pathlib import Path
 from typing import TypeVar, Generic
@@ -38,7 +39,7 @@ if not hasattr(typing, "Self"):
 ellipsis = ellipsis()
 Point = typing.Tuple[int, int]
 Variant = typing.Any
-QImageCleanupFunction = typing.Callable[..., typing.Any]
+QImageCleanupFunction = collections.abc.Callable[..., typing.Any]
 
 # unfortunately, typing.Optional[t] expands to typing.Union[t, NoneType]
 # Until we can force it to create Optional[t] again, we use this.
@@ -47,7 +48,7 @@ NoneType = type(None)
 # PYSIDE-2517: findChild/findChildren type hints:
 # Placeholder so it does not trigger an UNDEFINED error while building.
 # Later it will be bound to a QObject, within the QtCore types extensions
-PlaceHolderType = TypeVar("PlaceHolderType")
+PlaceholderType = TypeVar("PlaceholderType")
 
 _S = TypeVar("_S")
 
@@ -223,16 +224,16 @@ type_map.update({
     "int": int,
     "List": ArrayLikeVariable,
     "Optional": typing.Optional,
-    "Iterable": typing.Iterable,
+    "Iterable": collections.abc.Iterable,
     "long": int,
     "long long": int,
     "nullptr": None,
-    "PyCallable": typing.Callable[..., typing.Any],
+    "PyCallable": collections.abc.Callable[..., typing.Any],
     "PyObject": object,
     "PyObject*": object,
     "PyArrayObject": ArrayLikeVariable(typing.Any),  # numpy
     "PyPathLike": typing.Union[str, bytes, os.PathLike[str]],
-    "PySequence": typing.Iterable,  # important for numpy
+    "PySequence": collections.abc.Iterable,  # important for numpy
     "PyTypeObject": type,
     "QChar": str,
     "QHash": typing.Dict,
@@ -281,6 +282,8 @@ type_map.update({
     "short": int,
     "signed char": int,
     "signed long": int,
+    "std.chrono.milliseconds": int,
+    "std.chrono.seconds": int,
     "std.list": typing.List,
     "std.map": typing.Dict,
     "std.nullptr_t": NoneType,
@@ -496,7 +499,7 @@ def init_PySide6_QtCore():
         "NULL": None,  # 5.6, MSVC
         "nullptr": None,  # 5.9
         # PYSIDE-2517: findChild/findChildren type hints:
-        "PlaceHolderType": typing.TypeVar("PlaceHolderType", bound=PySide6.QtCore.QObject),
+        "PlaceholderType": typing.TypeVar("PlaceholderType", bound=PySide6.QtCore.QObject),
         "PyBuffer": typing.Union[bytes, bytearray, memoryview],
         "PyByteArray": bytearray,
         "PyBytes": typing.Union[bytes, bytearray, memoryview],
@@ -543,6 +546,8 @@ def init_PySide6_QtCore():
     # Here we manually set it to map to 'str'.
     type_map_tuple.update({("PySide6.QtCore.QObject.setProperty", "char*"): str})
     type_map_tuple.update({("PySide6.QtCore.QObject.property", "char*"): str})
+    type_map_tuple.update({("PySide6.QtCore.QObject.inherits", "char*"): str})
+    type_map_tuple.update({("PySide6.QtCore.qtTrId", "char*"): str})
 
     return locals()
 
@@ -740,6 +745,8 @@ missing_optional_return = {
     "PySide6.QtWidgets.QTableWidget.item",
     "PySide6.QtWidgets.QTableWidget.itemAt",
     "PySide6.QtWidgets.QTableWidget.mimeData",
+    "PySide6.QtWidgets.QTreeWidget.takeTopLevelItem",
+    "PySide6.QtWidgets.QTreeWidget.topLevelItem",
     "PySide6.QtWidgets.QWidget.childAt",
     "PySide6.QtWidgets.QWidget.find",
     "PySide6.QtWidgets.QWidget.focusProxy",
